@@ -72,7 +72,6 @@ var objPattern = new RegExp(
 "gi"
 );
 
-
 // Create an array to hold our data. Give the array
 // a default empty first row.
 var arrData = [[]];
@@ -134,6 +133,13 @@ arrData[ arrData.length - 1 ].push( strMatchedValue );
 return( arrData );
 }
 
+
+/*
+ params
+   0: Google Auth, encrypted
+   1: Google Query with auth key
+   2: Yahoo Query
+*/
 function doWebRequest(method, url, params, callback, show) {
     var doc = new XMLHttpRequest();
     //console.log(method + " " + url);
@@ -148,11 +154,12 @@ function doWebRequest(method, url, params, callback, show) {
         } else if (doc.readyState == XMLHttpRequest.DONE) {
             var data;
             var contentType = doc.getResponseHeader("Content-Type");
-            if (params>=1) {
-                data = doc.responseText;
+
+            if (params==1) {
+                data = doc.responseXML.documentElement;
             }
             else {
-                data = doc.responseXML.documentElement;
+                data = doc.responseText;
             }
 //            var dbg = doc.responseText;
 //            console.log(dbg);
@@ -161,7 +168,7 @@ function doWebRequest(method, url, params, callback, show) {
     }
 
     doc.open(method, url);
-    if(sid.length>0 && params<2) {
+    if(sid.length>0 && params==1) {
         // Google Finance ignore SID/LSID
         //console.log("Authorization GoogleLogin auth=" + sid);
         doc.setRequestHeader("Authorization", "GoogleLogin auth=" + sid);
@@ -170,7 +177,7 @@ function doWebRequest(method, url, params, callback, show) {
         //doc.setRequestHeader("Cookie", "SID=" + sidToken);
     }
 
-    if(params==1) {
+    if(params<2) {
         //console.log("Sending: " + params);
         doc.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
         doc.send();
@@ -193,11 +200,11 @@ function doWebRequestIdx(method, url, params, callback, idx, show) {
         } else if (doc.readyState == XMLHttpRequest.DONE) {
             var data;
             var contentType = doc.getResponseHeader("Content-Type");
-            if (params==1) {
-                data = doc.responseText;
+            if (params==1) {                
+                data = doc.responseXML.documentElement;
             }
             else {
-                data = doc.responseXML.documentElement;
+                data = doc.responseText;
             }
 //            var dbg = doc.responseText;
 //            console.log(dbg);
@@ -206,16 +213,14 @@ function doWebRequestIdx(method, url, params, callback, idx, show) {
     }
 
     doc.open(method, url);
+
     if(sid.length>0) {
         // Google Finance ignore SID/LSID
-        //console.log("Authorization GoogleLogin auth=" + sid);
         doc.setRequestHeader("Authorization", "GoogleLogin auth=" + sid);
-        // Specifying a version
         doc.setRequestHeader("GData-Version", "2");
-        //doc.setRequestHeader("Cookie", "SID=" + sidToken);
     }
 
-    if(params==1) {
+    if(params<2) {
         //console.log("Sending: " + params);
         doc.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
         doc.send();
@@ -228,9 +233,7 @@ function doWebRequestIdx(method, url, params, callback, idx, show) {
 function parseAuth(data, parameterName) {
     var parameterIndex = data.indexOf(parameterName + "=");
     if(parameterIndex<0) {
-        // We didn't find parameter
         console.log("Didn't find Auth");
-        //addError("Didn't find Auth");
         return "";
     }
     var equalIndex = data.indexOf("=", parameterIndex);
@@ -268,7 +271,7 @@ function login(email, password) {
     try {
         waiting.state = "login";
         var url = "https://www.google.com/accounts/ClientLogin?Email=" + encodeURIComponent(email) + "&Passwd=" + encodeURIComponent(password) + "&service=finance" + "&source=" + encodeURIComponent("stockona");
-        doWebRequest("POST", url, 1, parseToken, 0);
+        doWebRequest("POST", url, 0, parseToken, 0);
     }catch(err) {
         showError("Error while logging in: " + err, 1);
     }
@@ -291,12 +294,16 @@ function addError(msg) {
 }
 
 function loadAllPortfolios() {
-    itemsURL = "http://finance.google.com/finance/feeds/default/portfolios";
+    itemsURL = "https://finance.google.com/finance/feeds/default/portfolios";
     console.log(itemsURL);
     loadPortfolio();
 }
 
 function loadOnePosition(posFeedLink, pfoLocal, pfoIsYahoo, loadPosFromFile) {
+
+    // Replace http with https
+    posFeedLink = posFeedLink.replace("http", "https");
+
     console.log("loadOnePosition: " + posFeedLink + " " + pfoLocal + " " + pfoIsYahoo + " " + loadPosFromFile);
 
     if (pfoLocal) {
@@ -304,10 +311,9 @@ function loadOnePosition(posFeedLink, pfoLocal, pfoIsYahoo, loadPosFromFile) {
     }
     else {
         // Pull both return and transactions info
-        // itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/2/positions?returns=true";
         // itemsURL = posFeedLink+"?returns=true&transactions=true";
         itemsURL = posFeedLink+"?returns=true";
-        console.log(itemsURL);
+
         loadPosition();
     }
 }
@@ -343,7 +349,7 @@ function loadAllYahooQuote(quoteList, isYahooQuote) {
 }
 
 function loadOnePortfolio(PortfolioName) {
-    itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/"+PortfolioName;
+    itemsURL = "https://finance.google.com/finance/feeds/default/portfolios/"+PortfolioName;
     loadPortfolio();
 }
 
@@ -353,7 +359,7 @@ function loadPortfolio() {
         // pModel.clear();
         // Have to set to "portfolio", o.w. stategroup error message
         waiting.state = "shown";
-        doWebRequest("GET", itemsURL, 0, parsePortfolio, 1);
+        doWebRequest("GET", itemsURL, 1, parsePortfolio, 1);
     } catch(err) {
         showError("Error while loading portfolio: " + err, 1);
     }
@@ -362,7 +368,7 @@ function loadPortfolio() {
 function loadPortfolioNum(pfoIdx) {
     try {
         waiting.state = "shown";
-        doWebRequestIdx("GET", itemsURL, 0, parsePortfolioNum, pfoIdx, 1);
+        doWebRequestIdx("GET", itemsURL, 1, parsePortfolioNum, pfoIdx, 1);
     } catch(err) {
         showError("Error while loading portfolio num: " + err, 1);
     }
@@ -371,7 +377,7 @@ function loadPortfolioNum(pfoIdx) {
 function loadPosition() {
     try {
         waiting.state = "shown";
-        doWebRequest("GET", itemsURL, 0, parsePosition, 2);
+        doWebRequest("GET", itemsURL, 1, parsePosition, 2);
     } catch(err) {
         showError("Error while loading position: " + err, 1);
     }
@@ -431,7 +437,7 @@ function loadQuote(symObj, idx) {
 
     try {
         waiting.state = "shown";
-        doWebRequestIdx("GET", itemsURL, 1, parseJSON, idx, 3);
+        doWebRequestIdx("GET", itemsURL, 2, parseJSON, idx, 3);
     } catch(err) {
         showError("Error while loading g_quote: " + err, 1);
     }
@@ -495,6 +501,7 @@ function parsePortfolio(data) {
                 });
             }
             else {
+                //pfoCModel.append(false, false, 0, pfoName, pfoFeedLink, "-");
                 model.append({
                              "local": 0,
                              "name": pfoName,
@@ -573,41 +580,52 @@ function loadLocalPortfolio() {
             });
         }
     }
+    else if (fileOk==-2) {
+        error.reason = "Cannot load local portfolio.";
+        error.state = "shown";
+    }
 }
 
 function loadLocalPosition(pfoIdx, pfoIsYahoo, loadPosFromFile) {
 
+    var fileOk = 0;
+
     if (loadPosFromFile) {
-        fileHandler.loadPos(pfoIdx);
+        fileOk = fileHandler.loadPos(pfoIdx);
     }
 
     var quoteList = "";
 
-    for (var i=0; i<fileHandler.localPosSymbol.length; i++) {
-        console.log(i + ":" + fileHandler.localPosSymbol[i]);
+    if (fileOk==0) {
+        for (var i=0; i<fileHandler.localPosSymbol.length; i++) {
+            console.log(i + ":" + fileHandler.localPosSymbol[i]);
 
-        var symObj = {
-            "symName": fileHandler.localPosSymbol[i],
-            "symExg": fileHandler.localPosExg[i],
-            "symShare": fileHandler.localPosShare[i],
-            "shareCost": fileHandler.localPosCost[i],
-            "shareDayGain": 0,
-            "shareGain": 0,
-            "shareValue": 0,
-            "shareGainPercent": 0
-        };
+            var symObj = {
+                "symName": fileHandler.localPosSymbol[i],
+                "symExg": fileHandler.localPosExg[i],
+                "symShare": fileHandler.localPosShare[i],
+                "shareCost": fileHandler.localPosCost[i],
+                "shareDayGain": 0,
+                "shareGain": 0,
+                "shareValue": 0,
+                "shareGainPercent": 0
+            };
 
-        if (!pfoIsYahoo) {
-            loadOneQuote(symObj, i);
+            if (!pfoIsYahoo) {
+                loadOneQuote(symObj, i);
+            }
+            quoteList = quoteList + "+" + convertExchangeForYahoo(symObj.symName, symObj.symExg);
         }
-        quoteList = quoteList + "+" + convertExchangeForYahoo(symObj.symName, symObj.symExg);
+
+        // Take out leading +
+        quoteList = quoteList.replace(/^\+/, "");
+        loadAllYahooQuote(quoteList, pfoIsYahoo);
+
+    }
+    else if (fileOk==-2){
+        error.state = "shown";
+        error.reason = "Cannot load position file " + pfoIdx + ".pos";
     }
-
-    //waiting.reason = quoteList + "-" + fileHandler.localPosSymbol.length;
-
-    // Take out leading +
-    quoteList = quoteList.replace(/^\+/, "");
-    loadAllYahooQuote(quoteList, pfoIsYahoo);
 
     waiting.state = "hidden";
 }
@@ -782,8 +800,8 @@ function parseCSV(data) {
             for (var i=0; i<pModel.count; i=i+1) {
                 //console.log(i+":(Ask,Bid) = "+csvObj[i][0] + "/" + csvObj[i][1])
                 pModel.set(i, {
-                           "quoteAsk": (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
-                           "quoteBid": (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1]
+                           "quoteAsk": (csvObj[i][0]=="N/A"||csvObj[i][0]=="") ? "-" : csvObj[i][0],
+                           "quoteBid": (csvObj[i][1]=="N/A"||csvObj[i][0]=="") ? "-" : csvObj[i][1]
                 });
             }
         }
@@ -802,7 +820,7 @@ function parseCSV(data) {
                  var change = csvObj[i][7];
 
                  var quoteChgColor;
-                 if (change.match(/\+/)=="+") {
+                 if (change.indexOf("+")==0) {
                      quoteChgColor = "green";
                      //shareCost = formatNumber(shareValue/(1+parseFloat(gainPtg)));
                  }
@@ -901,8 +919,8 @@ function parseJSON(data, idx) {
     }
     else {
         var quoteChgColor;
-        var chgSymbol = jsonObj[0].c.match(/^\-/);
-        if (chgSymbol != null) {
+        //var chgSymbol = jsonObj[0].c.match(/^\-/);
+        if (jsonObj[0].c.indexOf("-")==0) { //chgSymbol != null) {
             quoteChgColor = "red";
         }
         else {
@@ -973,6 +991,10 @@ function cleanModel(model) {
 
 // Yahoo return 0 for ask/bid for non-North American exchange
 function convertExchangeForYahoo (name, exg) {
+    // replace .* with ^*
+    if (name.indexOf(".")==0)
+        return name.replace(".", "^");
+
     //console.log(name + exg);
     if (exg=="NYSE" || exg=="NASDAQ") { return name; }
     else if (exg=="OTC")              { return (name + "." + "OB"); }
